@@ -20,6 +20,7 @@ struct COOKIE_T {
   char *    string;
   BOOLEAN   session;
   BOOLEAN   secure;
+  BOOLEAN   persistent;
 };
 
 size_t COOKIESIZE = sizeof(struct COOKIE_T);
@@ -32,6 +33,8 @@ private char *   months[12] = {
   "Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"
 };
 
+char *__cookie_none = "none";
+
 /**
  * Creates a cookie with the value of the
  * Set-cookie header. 
@@ -45,14 +48,15 @@ new_cookie(char *str, char *host)
   COOKIE this;
 
   this = calloc(sizeof(struct COOKIE_T), 1);
-  this->name    = NULL;
-  this->value   = NULL;
-  this->domain  = NULL;
-  this->expires = 0;
-  this->expstr  = NULL;
-  this->string  = NULL;
-  this->session = TRUE;  
-  this->none    = strdup("none");
+  this->name       = NULL;
+  this->value      = NULL;
+  this->domain     = NULL;
+  this->expires    = 0;
+  this->expstr     = NULL;
+  this->string     = NULL;
+  this->session    = TRUE;  
+  this->persistent = FALSE;
+  this->none       = strdup(__cookie_none);
   if (__parse_input(this, str, host) == FALSE) {
     return cookie_destroy(this);
   }
@@ -120,6 +124,12 @@ cookie_set_expires(COOKIE this, time_t expires)
   this->expires = expires;
 }
 
+void 
+cookie_set_persistent(COOKIE this, BOOLEAN persistent)
+{
+  this->persistent = persistent;
+}
+
 /**
  * Returns the name of the cookie
  * Example: Set-Cookie: exes=X; expires=Fri, 01-May-2015 12:51:25 GMT
@@ -128,8 +138,8 @@ cookie_set_expires(COOKIE this, time_t expires)
 char *
 cookie_get_name(COOKIE this) 
 {
-  if (this == NULL && this->name == NULL) 
-    return this->none;
+  if (this == NULL || this->name == NULL) 
+    return __cookie_none;
   return this->name;
 }
 
@@ -141,8 +151,8 @@ cookie_get_name(COOKIE this)
 char * 
 cookie_get_value(COOKIE this) 
 {
-  if (this == NULL && this->value == NULL) 
-    return this->none;
+  if (this == NULL || this->value == NULL) 
+    return __cookie_none;
   return this->value;
 }
 
@@ -152,8 +162,8 @@ cookie_get_value(COOKIE this)
 char *
 cookie_get_domain(COOKIE this)
 {
-  if (this == NULL && this->domain == NULL) 
-    return this->none;
+  if (this == NULL || this->domain == NULL) 
+    return __cookie_none;
   return this->domain;
 }
 
@@ -163,8 +173,8 @@ cookie_get_domain(COOKIE this)
 char * 
 cookie_get_path(COOKIE this)
 {
-  if (this == NULL && this->path == NULL)
-    return this->none;
+  if (this == NULL || this->path == NULL)
+    return __cookie_none;
   return this->path;
 }
 
@@ -184,6 +194,14 @@ cookie_get_session(COOKIE this)
   return this->session;
 }
 
+BOOLEAN
+cookie_get_persistent(COOKIE this)
+{
+  if (this == NULL) 
+    return TRUE;
+  return this->persistent;
+}
+
 /**
  * Returns the string value of the cookie
  * (Mainly a debugging tool; we want cookie_expires for anything useful)
@@ -195,9 +213,6 @@ cookie_get_session(COOKIE this)
 char *
 cookie_expires_string(COOKIE this)
 {
-  /*if (this->expstr == NULL) 
-    this->expstr = malloc(sizeof (char*) * 128);
-  else */
   this->expstr = realloc(this->expstr, sizeof(this->expstr)*128);
   memset(this->expstr, '\0', 128);
   struct tm * timeinfo;
@@ -217,9 +232,10 @@ cookie_to_string(COOKIE this)
   memset(this->string, '\0', len);
  
   snprintf(
-    this->string, len, "%s=%s; domain=%s; path=%s; expires=%lld",
+    this->string, len, "%s=%s; domain=%s; path=%s; expires=%lld%s",
     this->name, this->value, (this->domain != NULL) ? this->domain : "none", 
-    (this->path != NULL) ? this->path : "/", (long long)this->expires
+    (this->path != NULL) ? this->path : "/", (long long)this->expires,
+    (this->persistent == TRUE) ? "; persistent=true" : ""
   ); 
   return this->string;
 }
@@ -248,10 +264,10 @@ cookie_reset_value(COOKIE this, char *value)
 COOKIE 
 cookie_clone(COOKIE this, COOKIE that) 
 {
-  this->value   = strealloc(this->value,  cookie_get_value(that)); 
-  this->domain  = strealloc(this->domain, cookie_get_domain(that));
-  this->path    = strealloc(this->path,   cookie_get_path(that));
-  //if ((time_t*)cookie_get_expires(that) != 0) {
+  this->value     = strealloc(this->value,  cookie_get_value(that)); 
+  this->domain    = strealloc(this->domain, cookie_get_domain(that));
+  this->path      = strealloc(this->path,   cookie_get_path(that));
+  this->persistent = cookie_get_persistent(that);
   if (this->expires > 0) {
     this->expires = time((time_t*)cookie_get_expires(that));
   }
@@ -322,6 +338,10 @@ __parse_input(COOKIE this, char *str, char *host)
       cookie_set_domain(this, val);
     } else if (!strncasecmp(key, "secure", 6)) {
       this->secure = TRUE;
+    } else if (!strncasecmp(key, "persistent", 10)) {
+      if (!strncasecmp(val, "true", 4)) {
+        this->persistent = TRUE;
+      }
     } else {
       this->name  = strdup(key);
       this->value = strdup(val);
