@@ -38,12 +38,14 @@ void    cookie_reset_value(COOKIE this, char *str);
 void    cookie_set_path(COOKIE this, char *str);
 void    cookie_set_domain(COOKIE this, char *str);
 void    cookie_set_expires(COOKIE this, time_t expires);
+void    cookie_set_persistent(COOKIE this, BOOLEAN persistent);
 char *  cookie_get_name(COOKIE this);
 char *  cookie_get_value(COOKIE this);
 char *  cookie_get_domain(COOKIE this);
 char *  cookie_get_path(COOKIE this);
 time_t  cookie_get_expires(COOKIE this);
 BOOLEAN cookie_get_session(COOKIE this);
+BOOLEAN cookie_get_persistent(COOKIE this);
 char *  cookie_expires_string(COOKIE this);
 char *  cookie_to_string(COOKIE this);
 COOKIE  cookie_clone(COOKIE this, COOKIE that);
